DatasourceGetRemote<RemoteObject extends Codable<Object, RemoteObject> , Driver extends RemoteDriver> class
abstract
base
A specialized DatasourceRemote for handling HTTP GET operations.
Use this class to fetch data from a remote server without side effects. This is the most common class for read-only operations.
- Inheritance
-
- Object
- DataSource
- DataSourceCallable<
RemoteObject> - DatasourceRemote<
RemoteObject, Driver> - DatasourceGetRemote
- Mixed-in types
-
- GetCall<
RemoteObject, Driver>
- GetCall<
Constructors
- DatasourceGetRemote({required Driver driver})
- A specialized DatasourceRemote for handling HTTP GET operations.
Properties
-
admissibleStatusCode
→ Set<
int> -
Set of http status codes that are considered admissible.
no setterinherited
- driver → Driver
-
The underlying RemoteDriver instance used to execute remote operations.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
host of the provide information, can contains port and scheme
no setterinherited
-
inadmissibleStatusCode
→ Set<
int> -
Set of http status codes that are considered inadmissible.
no setterinherited
- observer → HttpDatasourceObserver
-
Retrieves the standard observer instance used to track the lifecycle
and events of all Data Sources in the application.
no setterinherited
- path → String?
-
path of the provide information
no setterinherited
-
pathModification
→ Map<
String, String> -
path of the provide information
no setterinherited
- pathPrefix → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
Current url transformation to URI.
no setterinherited
Methods
-
call(
{required covariant Params params}) → Future< RemoteObject> -
Manage the server connection.
inherited
-
checkInformation(
{required covariant RequestResponse requestResponse, required Map< String, String> ? requestHeaders, required Uri? requestUri, Object? requestBody}) → FutureOr<RemoteObject> -
Usually use after server call to return the required data or failure.
inherited
-
dispose(
) → void -
Called when the DataSource instance is no longer needed and should
release any held resources (e.g., closing connections, unregistering listeners).
inherited
-
generateCallRequirement(
{required covariant Params params}) → GetParams -
Generates the specific parameters required for a GET request.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
RequestParams requestParams) → Future< RemoteObject> -
Centralized method to handle all HTTP requests.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transformation(
{required covariant RequestResponse remoteResponse}) → FutureOr< RemoteObject> -
Function call after response success.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited