RepositoryDataSourceCallableObserver class abstract interface

Observer for repositories that execute one-shot operations.

Implemented types
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterCall(String name, String datasourceName, Object? datasourceValue) → void
Called after the DataSource finishes execution.
beforeCall(String name, String callableName) → void
Called just before invoking the underlying DataSource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCreate(String name) → void
Called immediately after a component has been successfully created and initialized.
inherited
onDispose(String name) → void
Called immediately before a component is permanently disposed of or closed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited