RepositoryDataSourceStreamableObserver class abstract interface

Interface for monitoring repositories that establish continuous data flows.

Unlike callable observers that track execution and completion, this observer focuses on the connection lifecycle of a Stream.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCreate(String name) → void
Called immediately after a component has been successfully created and initialized.
inherited
onDispose(String name) → void
Called immediately before a component is permanently disposed of or closed.
inherited
start(String name, String callableName) → void
Called when the repository starts listening to the underlying DataSourceStreamable.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited