DatasourceObserverInstances class
Static registry for Data Source observers.
By default, Data Shaft provides implementations that log to the console
using dart:developer. You can replace them with your own implementations:
DatasourceObserverInstances.httpDatasourceObserver = MyCustomSentryObserver();
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- datasourceObserver ↔ SimpleDatasourceObserver
-
Returns the current simple observer or a default developer log implementation.
getter/setter pair
- httpDatasourceObserver ↔ HttpDatasourceObserver
-
Returns the current HTTP observer or a default developer log implementation.
getter/setter pair