DatasourcePutRemote<RemoteObject extends Codable<Object, RemoteObject> , Driver extends RemoteDriver> class
abstract
base
A specialized DatasourceRemote for handling HTTP PUT operations.
Use this class when you need to replace an existing resource entirely on the server. It utilizes the PutCall mixin to manage the request lifecycle.
- Inheritance
-
- Object
- DataSource
- DataSourceCallable<
RemoteObject> - DatasourceRemote<
RemoteObject, Driver> - DatasourcePutRemote
- Mixed-in types
-
- PutCall<
RemoteObject, Driver>
- PutCall<
Constructors
- DatasourcePutRemote({required Driver driver})
- A specialized DatasourceRemote for handling HTTP PUT operations.
Properties
-
admissibleStatusCode
→ List<
int> -
List of http status code with the admissible status codes.
no setterinherited
- driver → Driver
-
The underlying RemoteDriver instance used to execute remote operations.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
host of the provide information, can contains port and scheme
no setterinherited
-
inadmissibleStatusCode
→ List<
int> -
List of http status code with the inadmissible status codes.
no setterinherited
- observer → HttpDatasourceObserver
-
Retrieves the standard observer instance used to track the lifecycle
and events of all Data Sources in the application.
no setterinherited
- path → String?
-
path of the provide information
no setterinherited
-
pathModification
→ Map<
String, String> -
path of the provide information
no setterinherited
- pathPrefix → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
Current url transformation to URI.
no setterinherited
Methods
-
call(
{required covariant Params params}) → Future< RemoteObject> -
Manage the server connection.
inherited
-
checkInformation(
{required covariant RequestResponse requestResponse, required Map< String, String> ? requestHeaders, required Uri? requestUri, Object? requestBody}) → FutureOr<RemoteObject> -
Usually use after server call to return the required data or failure.
inherited
-
dispose(
) → void -
Called when the DataSource instance is no longer needed and should
release any held resources (e.g., closing connections, unregistering listeners).
inherited
-
generateCallRequirement(
{required covariant Params params}) → PutParams -
Generates the specific parameters required for a PUT request.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
RequestParams requestParams) → Future< RemoteObject> -
Centralized method to handle all HTTP requests.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transformation(
{required covariant RequestResponse remoteResponse}) → FutureOr< RemoteObject> -
Function call after response success.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited