Driver class abstract
The fundamental abstraction for all Data Drivers within the Data Layer.
A Driver acts as a low-level utility to handle connectivity or data retrieval logic before it is processed by a higher-level DataSource.
Drivers are typically categorized into two main types: Basic (local) and Remote (network).
This base class enforces a uniform type for utilities, ensuring a clean separation of concerns and testability.
- Implementers
Constructors
- Driver()
-
The fundamental abstraction for all Data Drivers within the Data Layer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited