Interface for monitoring the basic lifecycle of any DataSource.
It tracks when a data source is initialized in memory and when it is disposed, helping to detect memory leaks or unexpected recreations.
- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCreate(
String name) → void -
Called immediately after a component has been successfully created and initialized.
override
-
onDispose(
String name) → void -
Called immediately before a component is permanently disposed of or closed.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited